@@ -16,6 +16,8 @@ module Text.CSL.Data
     ( getLocale
     , CSLLocaleException(..)
     , getDefaultCSL
+    , getManPage
+    , getLicense
     , langBase
     ) where
 
@@ -25,7 +27,7 @@ import qualified Data.ByteString.Lazy as L
 import qualified Control.Exception as E
 #ifdef EMBED_DATA_FILES
 import Data.Maybe (fromMaybe)
-import Text.CSL.Data.Embedded (localeFiles, defaultCSL)
+import Text.CSL.Data.Embedded (localeFiles, defaultCSL, manpage, license)
 #else
 import Paths_pandoc_citeproc (getDataFileName)
 import System.Directory  (doesFileExist)
@@ -81,6 +83,22 @@ getDefaultCSL =
   getDataFileName "chicago-author-date.csl" >>= L.readFile
 #endif
 
+getManPage :: IO L.ByteString
+getManPage =
+#ifdef EMBED_DATA_FILES
+  return $ L.fromChunks [manpage]
+#else
+  getDataFileName "man/man1/pandoc-citeproc.1" >>= L.readFile
+#endif
+
+getLicense :: IO L.ByteString
+getLicense =
+#ifdef EMBED_DATA_FILES
+  return $ L.fromChunks [license]
+#else
+  getDataFileName "LICENSE" >>= L.readFile
+#endif
+
 langBase :: [(String, String)]
 langBase
     = [("af", "af-ZA")
