@@ -119,18 +119,15 @@ formatNames ea del p s as n
 
     | EtAl fm t <- n = do
         o <- gets (options . env)
-        if (getOptionVal "et-al-min" o == [])
-           then return []
-           else do
-             et <- gets etal
-             let i = length as - length et
-                 t' = if null t then "et-al" else t
-             r <- mapM (et_al o False t' fm del) [i .. length as]
-             let (r',r'') = case r of
-                              (x:xs) -> (x, xs)
-                              []     -> ([],[])
-             updateEtal r''
-             return r'
+        et <- gets etal
+        let i = length as - length et
+            t' = if null t then "et-al" else t
+        r <- mapM (et_al o False t' fm del) [i .. length as]
+        let (r',r'') = case r of
+                         (x:xs) -> (x, xs)
+                         []     -> ([],[])
+        updateEtal r''
+        return r'
 
     | otherwise = return []
     where
@@ -350,6 +347,7 @@ formatLabel f fm p s
                        form (\fm' -> return . flip OLoc emptyFormatting . output fm') id l (isRange v)
     | "page"    <- s = checkPlural
     | "volume"  <- s = checkPlural
+    | "issue"   <- s = checkPlural
     | "ibid"    <- s = format s p
     | isRole       s = do a <- getAgents' (if s == "editortranslator"
                                               then "editor"
