@@ -1,5 +1,5 @@
+{-# LANGUAGE ScopedTypeVariables #-}
 {-# OPTIONS_GHC -fno-warn-unused-do-bind #-}
-{-# LANGUAGE CPP #-}
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  Text.CSL.Input.Bibtex
@@ -15,15 +15,17 @@ module Text.CSL.Input.Bibtex
     ( readBibtex
     , readBibtexString
     , readBibtexString'
+    , Lang(..)
+    , langToLocale
+    , getLangFromEnv
     )
     where
 
 import Text.Parsec hiding (optional, (<|>), many, State)
 import Control.Applicative
-import Text.Pandoc (readLaTeX, ReaderOptions(..))
+import Text.CSL.Compat.Pandoc (readLaTeX)
 import Text.Pandoc.Definition
 import Text.Pandoc.Generic (bottomUp)
-import Data.Default (Default(def))
 import Data.List.Split (splitOn, splitWhen, wordsBy)
 import Data.List (intercalate)
 import Data.Maybe
@@ -33,7 +35,8 @@ import Control.Monad.RWS
 import System.Environment (getEnvironment)
 import Text.CSL.Reference
 import Text.CSL.Style (Formatted(..), Locale(..), CslTerm(..), Agent(..))
-import Text.CSL.Util (trim, onBlocks, unTitlecase, protectCase, splitStrWhen)
+import Text.CSL.Util (trim, onBlocks, unTitlecase, protectCase, splitStrWhen,
+                      safeRead)
 import Text.CSL.Parser (parseLocale)
 import qualified Text.Pandoc.Walk as Walk
 import qualified Text.Pandoc.UTF8 as UTF8
@@ -48,7 +51,7 @@ blocksToFormatted bs =
 adjustSpans :: Lang -> Inline -> [Inline]
 adjustSpans _ (Span ("",[],[]) xs) = xs
 adjustSpans lang (RawInline (Format "latex") s)
-  | s == "\\hyphen" = [Str "-"]
+  | s == "\\hyphen" || s == "\\hyphen " = [Str "-"]
   | otherwise = bottomUp (concatMap (adjustSpans lang)) $ parseRawLaTeX lang s
 adjustSpans _ x = [x]
 
@@ -84,6 +87,7 @@ data Item = Item{ identifier :: String
                 , fields     :: [(String, String)]
                 }
 
+-- | Get 'Lang' from the environment variable LANG, defaulting to en-US.
 getLangFromEnv :: IO Lang
 getLangFromEnv = do
   env <- getEnvironment
@@ -94,17 +98,23 @@ getLangFromEnv = do
                                    _                  -> Lang "en" "US"
                   Nothing -> Lang "en" "US"
 
+-- | Parse a BibTeX or BibLaTeX file into a list of 'Reference's.
+-- If the first parameter is true, the file will be treated as
+-- BibTeX; otherwse as BibLaTeX.  If the second parameter is
+-- true, an "untitlecase" transformation will be performed.
 readBibtex :: Bool -> Bool -> FilePath -> IO [Reference]
 readBibtex isBibtex caseTransform f =
   UTF8.readFile f >>= readBibtexString isBibtex caseTransform
 
+-- | Like 'readBibtex' but operates on a String rather than a file.
 readBibtexString :: Bool -> Bool -> String -> IO [Reference]
 readBibtexString isBibtex caseTransform contents = do
   lang <- getLangFromEnv
   locale <- parseLocale (langToLocale lang)
   return $ readBibtexString' isBibtex caseTransform lang locale contents
 
--- pure version of readBibtexString
+-- | Pure version of readBibtexString (does not try to get the language
+-- from the environment).
 readBibtexString' :: Bool -> Bool -> Lang -> Locale -> String -> [Reference]
 readBibtexString' isBibtex caseTransform lang locale bibstring =
   let items = case runParser (bibEntries <* eof) [] "stdin" bibstring of
@@ -172,10 +182,10 @@ inQuotes = do
                       ) (char '"')
 
 fieldName :: BibParser String
-fieldName = (map toLower) <$> many1 (letter <|> digit <|> oneOf "-_:")
+fieldName = (map toLower) <$> many1 (letter <|> digit <|> oneOf "-_:+")
 
 isBibtexKeyChar :: Char -> Bool
-isBibtexKeyChar c = isAlphaNum c || c `elem` ".:;?!`'()/*@_+=-[]*"
+isBibtexKeyChar c = isAlphaNum c || c `elem` ".:;?!`'()/*@_+=-[]*&"
 
 bibItem :: BibParser Item
 bibItem = do
@@ -333,8 +343,10 @@ bookTrans z =
        "indexsorttitle" -> []
        _                -> [z]
 
+-- | A representation of a language and localization.
 data Lang = Lang String String  -- e.g. "en" "US"
 
+-- | Prints a 'Lang' in BCP 47 format.
 langToLocale :: Lang -> String
 langToLocale (Lang x y) = x ++ ('-':y)
 
@@ -903,22 +915,53 @@ getDates :: String -> Bib [RefDate]
 getDates f = getRawField f >>= parseDates
 
 parseDates :: Monad m => String-> m [RefDate]
-parseDates = mapM parseDate . splitWhen (== '/')
+parseDates s
+  | '/' `elem` s = mapM parseDate . splitWhen (== '/') $ s
+  -- 199u EDTF format for a range:
+  | 'u' `elem` s = let s1 = map (\c -> if c == 'u' then '0' else c) s
+                       s2 = map (\c -> if c == 'u' then '9' else c) s
+                   in  mapM parseDate [s1, s2]
+  | otherwise    = mapM parseDate [s]
 
 parseDate :: Monad m => String -> m RefDate
+-- EDTF format for year of more than 4 digits, starts with 'y':
+parseDate ('y':xs) = parseDate xs
+parseDate "open" = return RefDate { year = mempty,
+                         month = mempty, season = mempty, day = mempty,
+                         other = mempty, circa = False }
+parseDate "unknown" = return RefDate { year = mempty,
+                         month = mempty, season = mempty, day = mempty,
+                         other = mempty, circa = False }
 parseDate s = do
+  let circa' = '~' `elem` s
   let (year', month', day') =
-        case splitWhen (== '-') s of
-             [y]     -> (y, mempty, mempty)
-             [y,m]   -> (y, m, mempty)
-             [y,m,d] -> (y, m, d)
-             _       -> (mempty, mempty, mempty)
-  return RefDate { year   = Literal $ dropWhile (=='0') year'
-                 , month  = Literal $ dropWhile (=='0') month'
-                 , season = mempty
+        case splitWhen (== '-') $ filter (`notElem` "~?")
+                                -- drop time component:
+                                $ takeWhile (/='T') s of
+             -- initial - is negative year:
+             ["",y]     -> ('-':y, mempty, mempty)
+             ["",y,m]   -> ('-':y, m, mempty)
+             ["",y,m,d] -> ('-':y, m, d)
+             [y]        -> (y, mempty, mempty)
+             [y,m]      -> (y, m, mempty)
+             [y,m,d]    -> (y, m, d)
+             _          -> (mempty, mempty, mempty)
+  let year'' = case safeRead year' of
+                    -- EDTF 0 == CSL JSON -1 (1 BCE)
+                    Just (n :: Integer) | n <= 0 -> show (n - 1)
+                    _ -> year'
+  let (season'', month'') = case month' of
+                                 "21" -> ("1","")
+                                 "22" -> ("2","")
+                                 "23" -> ("3","")
+                                 "24" -> ("4","")
+                                 _ -> ("", month')
+  return RefDate { year   = Literal $ dropWhile (=='0') year''
+                 , month  = Literal $ dropWhile (=='0') month''
+                 , season = Literal season''
                  , day    = Literal $ dropWhile (=='0') day'
                  , other  = mempty
-                 , circa  = False
+                 , circa  = circa'
                  }
 
 isNumber :: String -> Bool
@@ -1091,15 +1134,8 @@ optionSet key opts = case lookup key opts of
                       _           -> False
 
 latex' :: String -> [Block]
-latex' s = Walk.walk removeSoftBreak $
-#if MIN_VERSION_pandoc(1,14,0)
-  case readLaTeX def{readerParseRaw = True, readerSmart = True} s of
-                Right (Pandoc _ bs) -> bs
-                _                   -> []
-#else
-  case readLaTeX def{readerParseRaw = True, readerSmart = True} s of
-                Pandoc _ bs         -> bs
-#endif
+latex' s = Walk.walk removeSoftBreak bs
+  where Pandoc _ bs = readLaTeX s
 
 removeSoftBreak :: Inline -> Inline
 removeSoftBreak SoftBreak = Space
