@@ -186,9 +186,18 @@ hasLowercaseWord = any startsWithLowercase . splitStrWhen isPunctuation
 
 splitUpStr :: [Inline] -> [Inline]
 splitUpStr ils =
-  case reverse (splitStrWhen (\c -> isPunctuation c || c == '\160') ils) of
-       [] -> []
-       (x:xs) -> reverse $ Span ("",["lastword"],[]) [x] : xs
+  case reverse (combineInternalPeriods
+         (splitStrWhen (\c -> isPunctuation c || c == '\160') ils)) of
+         [] -> []
+         (x:xs) -> reverse $ Span ("",["lastword"],[]) [x] : xs
+
+-- We want to make sure that the periods in www.example.com, for
+-- example, are not interpreted as sentence-ending punctuation.
+combineInternalPeriods :: [Inline] -> [Inline]
+combineInternalPeriods [] = []
+combineInternalPeriods (Str xs:Str ".":Str ys:zs) =
+  combineInternalPeriods $ Str (xs ++ "." ++ ys) : zs
+combineInternalPeriods (x:xs) = x : combineInternalPeriods xs
 
 unTitlecase :: [Inline] -> [Inline]
 unTitlecase zs = evalState (caseTransform untc zs) SentenceBoundary
@@ -286,7 +295,7 @@ caseTransform xform = fmap reverse . foldM go [] . splitUpStr
                put WordBoundary
                return $ Space : acc
         go acc (Str [c])
-          | c `elem` "-/\2013\2014\160" = do
+          | c `elem` "-/\x2013\x2014\160" = do
                put WordBoundary
                return $ Str [c] : acc
           | isPunctuation c = do
@@ -416,11 +425,17 @@ mapHeadInline f (i:xs)
 
 findFile :: [FilePath] -> FilePath -> IO (Maybe FilePath)
 findFile [] _ = return Nothing
-findFile (p:ps) f = do
-  exists <- doesFileExist (p </> f)
-  if exists
-     then return $ Just (p </> f)
-     else findFile ps f
+findFile (p:ps) f
+ | isAbsolute f = do
+     exists <- doesFileExist f
+     if exists
+        then return (Just f)
+        else return Nothing
+ | otherwise = do
+     exists <- doesFileExist (p </> f)
+     if exists
+        then return $ Just (p </> f)
+        else findFile ps f
 
 (&=) :: (ToYaml a, Monoid a, Eq a)
      => Text -> a -> [(Text, YamlBuilder)] -> [(Text, YamlBuilder)]
