@@ -1,33 +1,26 @@
 {-# LANGUAGE OverloadedStrings, TypeSynonymInstances, FlexibleInstances,
-    ScopedTypeVariables #-}
-import JSON
+    ScopedTypeVariables, CPP #-}
+
 import Text.Printf
 import System.Exit
 import qualified Control.Exception as E
-import Text.Pandoc
+import Text.Pandoc (Block(..), Inline(..), Format(..), bottomUp,
+   nullMeta, Pandoc(..))
+import Text.CSL.Compat.Pandoc (writeHtmlString)
 import Data.Char (isSpace, toLower)
 import System.Environment (getArgs)
 import System.Process
 import System.IO.Temp (withSystemTempDirectory)
-import Text.Pandoc.Definition (Inline(Span, Str))
-import Text.Pandoc.Generic
-import Text.Pandoc.Walk
 import qualified Text.Pandoc.UTF8 as UTF8
-import Data.Maybe (mapMaybe)
 import Data.Aeson
-import Data.Aeson.Types (Parser)
 import System.FilePath
 import System.Directory
-import Data.List (intercalate, sort, isInfixOf)
-import qualified Data.Vector as V
+import Data.List (sort, isInfixOf)
 import qualified Data.Map as M
-import qualified Data.Text as T
-import qualified Data.Text.Encoding as T
 import Text.CSL.Style hiding (Number)
 import Text.CSL.Reference
 import Text.CSL
 import Control.Monad
-import Control.Applicative
 import qualified Data.ByteString.Lazy as BL
 
 data TestCase = TestCase{
@@ -60,7 +53,7 @@ instance FromJSON TestCase where
               v .:? "bibsection" .!= Select [] [] <*>
               v .:? "citations" .!= [] <*>
               v .:? "citation_items" .!= [] <*>
-              v .:  "csl" <*>
+              (parseCSL <$> (v .:  "csl")) <*>
               v .:? "abbreviations" .!= (Abbreviations M.empty) <*>
               v .:  "input" <*>
               v .:  "result"
@@ -78,9 +71,12 @@ instance FromJSON CiteObject where
          x               -> fail $ "Could not parse CiteObject" ++ show x
   parseJSON x = fail $ "Could not parse CiteObject " ++ show x
 
+#if MIN_VERSION_aeson(0,10,0)
+#else
 instance FromJSON [CiteObject] where
   parseJSON (Array v) = mapM parseJSON $ V.toList v
   parseJSON _ = return []
+#endif
 
 data TestResult =
     Passed
@@ -92,16 +88,16 @@ data TestResult =
 testDir :: FilePath
 testDir = "citeproc-test" </> "processor-tests" </> "machines"
 
-handleError :: FilePath -> E.SomeException -> IO TestResult
-handleError path e = do
+handler :: FilePath -> E.SomeException -> IO TestResult
+handler path e = do
   putStrLn $ "[ERROR] " ++ path ++ "\n" ++ show e
   return Errored
 
 runTest :: FilePath -> IO TestResult
-runTest path = E.handle (handleError path) $ do
+runTest path = E.handle (handler path) $ do
   raw <- BL.readFile path
   let testCase = either error id $ eitherDecode raw
-  let procOpts = ProcOpts (testBibopts testCase) False
+  let procOpts' = ProcOpts (testBibopts testCase) False
   style <- localizeCSL Nothing
            $ (testCsl testCase) { styleAbbrevs = testAbbreviations testCase }
   let refs     = testReferences testCase
@@ -127,7 +123,7 @@ runTest path = E.handle (handleError path) $ do
          let result   = assemble mode
               $ map (inlinesToString . renderPandoc style) $
                 (case mode of {CitationMode -> citations; _ -> bibliography})
-                $ citeproc procOpts style refs cites'
+                $ citeproc procOpts' style refs cites'
          if result == expected
             then do
               putStrLn $ "[PASSED] " ++ path ++ "\n"
@@ -144,7 +140,7 @@ trimEnd = reverse . ('\n':) . dropWhile isSpace . reverse
 -- this is designed to mimic the test suite's output:
 inlinesToString  :: [Inline]  -> String
 inlinesToString ils =
-  writeHtmlString def{ writerWrapText = WrapNone }
+  writeHtmlString
     $ bottomUp (concatMap adjustSpans)
     $ Pandoc nullMeta [Plain ils]
 
