@@ -1,11 +1,11 @@
 {-# LANGUAGE CPP #-}
+{-# LANGUAGE ScopedTypeVariables #-}
 module Main where
 import System.Exit
 import System.Directory
 import System.FilePath
 import Data.Maybe (fromMaybe)
 import System.IO
-import Data.Monoid (mempty)
 import System.IO.Temp (withSystemTempDirectory)
 import System.Process (rawSystem)
 import qualified Data.Aeson as Aeson
@@ -15,6 +15,9 @@ import Text.CSL.Compat.Pandoc (writeNative, pipeProcess)
 import Data.List (isSuffixOf)
 import System.Environment
 import Control.Monad (when)
+#if MIN_VERSION_pandoc(2,0,0)
+import qualified Control.Exception as E
+#endif
 
 main :: IO ()
 main = do
@@ -99,8 +102,16 @@ showDiff expected result =
 biblio2yamlTest :: String -> IO TestResult
 biblio2yamlTest fp = do
   hPutStr stderr $ "[biblio2yaml/" ++ fp ++ "] "
-  let yamlf = "tests/biblio2yaml/" ++ fp
-  raw <- UTF8.readFile yamlf
+  let yamld = "tests/biblio2yaml/"
+#if MIN_VERSION_pandoc(2,0,0)
+  -- in a few cases we need different test output for pandoc >= 2
+  -- because smallcaps render differently, for example.
+  raw <- E.catch (UTF8.readFile (yamld ++ "/pandoc-2/" ++ fp))
+         (\(_ :: E.SomeException) ->
+           (UTF8.readFile (yamld ++ fp)))
+#else
+  raw <- UTF8.readFile (yamld ++ fp)
+#endif
   let yamlStart = "---"
   let (biblines, yamllines) = break (== yamlStart) $ lines raw
   let bib = unlines biblines
